"""
Admin site configurations for integrated channel's Content Metadata Transmission table.
"""

from django.contrib import admin

from integrated_channels.integrated_channel.models import ContentMetadataItemTransmission


@admin.register(ContentMetadataItemTransmission)
class ContentMetadataItemTransmissionAdmin(admin.ModelAdmin):
    """
    Admin for the ContentMetadataItemTransmission audit table
    """
    list_display = ('enterprise_customer', 'integrated_channel_code', 'content_id', 'channel_metadata')
    search_fields = ('enterprise_customer', 'integrated_channel_code', 'content_id')

    def has_add_permission(self, request):
        return False

    def has_change_permission(self, request, obj=None):
        return False



# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2019-11-07 15:36


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0077_auto_20191002_1529'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='enterprisecustomeruser',
            options={'ordering': ['active', '-modified'], 'verbose_name': 'Enterprise Customer Learner', 'verbose_name_plural': 'Enterprise Customer Learners'},
        ),
    ]



# -*- coding: utf-8 -*-


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('consent', '0002_migrate_to_new_data_sharing_consent'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicaldatasharingconsent',
            name='history_change_reason',
            field=models.CharField(max_length=100, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-10-15 16:12


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0054_merge_20180914_1511'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_autocohorting',
            field=models.BooleanField(default=False, help_text='Specifies whether the customer is able to assign learners to cohorts upon enrollment.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_autocohorting',
            field=models.BooleanField(default=False, help_text='Specifies whether the customer is able to assign learners to cohorts upon enrollment.'),
        ),
    ]



# -*- coding: utf-8 -*-


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0025_auto_20170828_1412'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecustomer',
            name='require_account_level_consent',
            field=models.NullBooleanField(default=False, help_text='Specifies whether every consent interaction should ask for account-wide consent, rather than only the specific scope at which the interaction is happening.'),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecustomer',
            name='require_account_level_consent',
            field=models.NullBooleanField(default=False, help_text='Specifies whether every consent interaction should ask for account-wide consent, rather than only the specific scope at which the interaction is happening.'),
        ),
    ]



# -*- coding: utf-8 -*-
"""
Reset SAPSF learner transmissions between two dates.
"""

from django.apps import apps
from django.core.management.base import BaseCommand
from django.utils.dateparse import parse_datetime
from django.utils.translation import ugettext as _


class Command(BaseCommand):
    """
    Management command which resets SAPSF learner course completion data between two dates.
    That would allow us to resend course completion data.

    `./manage.py lms reset_sapsf_learner_transmissions
    --start_datetime=2020-01-14T00:00:00Z --end_datetime=2020-01-14T15:11:00Z`
    """
    help = _('''
    Reset SAPSF learner transmissions for the given EnterpriseCustomer and Channel between two dates.
    ''')

    def add_arguments(self, parser):
        """
        Add required --start_datetime and --end_datetime arguments to the parser.
        """
        parser.add_argument(
            '--start_datetime',
            dest='start_datetime',
            required=True,
            help=_('Start date and time in YYYY-MM-DDTHH:MM:SSZ format.'),
        )

        parser.add_argument(
            '--end_datetime',
            dest='end_datetime',
            required=True,
            help=_('End date and time in YYYY-MM-DDTHH:MM:SSZ format.'),
        )

        super().add_arguments(parser)

    def handle(self, *args, **options):
        """
        Resets SAPSF learner course completion data between two dates.
        """
        start_datetime = parse_datetime(options['start_datetime'])
        end_datetime = parse_datetime(options['end_datetime'])

        if not start_datetime or not end_datetime:
            self.stdout.write(self.style.ERROR("FAILED: start or end dates times are not valid"))
            return

        SapSuccessFactorsLearnerDataTransmissionAudit = apps.get_model(  # pylint: disable=invalid-name
            'sap_success_factors',
            'SapSuccessFactorsLearnerDataTransmissionAudit'
        )
        enrollment_ids = SapSuccessFactorsLearnerDataTransmissionAudit.objects.filter(
            created__gte=start_datetime, created__lte=end_datetime
        ).values_list('enterprise_course_enrollment_id', flat=True)

        for enrollment_id in enrollment_ids:
            SapSuccessFactorsLearnerDataTransmissionAudit.objects.filter(
                enterprise_course_enrollment_id=enrollment_id,
                error_message=''
            ).update(error_message='Invalid data sent', status='400')
            self.stdout.write(
                self.style.SUCCESS('Successfully updated transmissions with these enrollment id ["%s"]' % enrollment_id)
            )
